-- -----------------------------------------------------
SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

-- -----------------------------------------------------
-- Table `vivdocs`.`calendar name`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`calendar`;

CREATE TABLE  `vivdocs`.`calendar` (
  `calendar_id` SMALLINT NOT NULL ,
  `calendar_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `calendar_name` VARCHAR (127) NOT NULL ,
  PRIMARY KEY  (`calendar_id`)
) ENGINE=InnoDB;

INSERT INTO `vivdocs`.`calendar` (calendar_id,calendar_modified,calendar_name) 
VALUES (0,'2000-01-01','Государственный календарь РФ');

-- -----------------------------------------------------
-- Table `vivdocs`.`calendar`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`day`;

CREATE TABLE  `vivdocs`.`day` (
  `day_calendar_id` SMALLINT NOT NULL ,
  `day_date` DATE NOT NULL ,
  `day_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `day_category` TINYINT NOT NULL ,
  PRIMARY KEY  (`day_calendar_id`,`day_date`) ,
  CONSTRAINT `FK_CALENDAR`
    FOREIGN KEY (`day_calendar_id` )
    REFERENCES `vivdocs`.`calendar` (`calendar_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
) ENGINE=InnoDB;

CREATE INDEX IDX_CALENDAR_MODIFIED ON `vivdocs`.`day` (`day_modified` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`Threads`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`thread`;

CREATE TABLE  `vivdocs`.`thread` (
  `thread_name` VARCHAR(127) NOT NULL,
  `thread_lastrun` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `thread_success` TIMESTAMP NULL DEFAULT NULL,
  `thread_data` MEDIUMTEXT NULL,
  PRIMARY KEY  (`thread_name`)
) ENGINE=InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Portlets`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`portlet`;

CREATE TABLE  `vivdocs`.`portlet` (
  `portlet_uid` BINARY(16) NOT NULL,
  `portlet_title` VARCHAR(127) NOT NULL,
  `portlet_class` VARCHAR(256) NOT NULL,
  `portlet_context` VARCHAR(127) NULL,
  `portlet_restricted` TINYINT NOT NULL DEFAULT 0,
  `portlet_local` TINYINT NOT NULL DEFAULT 0,
  `portlet_data` MEDIUMBLOB NULL,
  `portlet_modified` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY  (`portlet_uid`)
) ENGINE=InnoDB;

CREATE INDEX IDX_PORTLET_CLASS ON `vivdocs`.`portlet` (`portlet_class` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`Sites`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`site` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`site` (
  `site_id` SMALLINT UNSIGNED NOT NULL AUTO_INCREMENT,
  `site_uid` BINARY(16) NOT NULL ,
  `site_name` VARCHAR(90) NULL ,
  `site_modified` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ,
  PRIMARY KEY (`site_id`) ,
  INDEX `IDX_SITE_MODIFIED` (`site_modified` ASC) ,
  UNIQUE INDEX `IDX_SITE_UID_UNIQUE` (`site_uid` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `vivdocs`.`DATA`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`subj` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`subj` (
  `subj_lid` INT NOT NULL ,
  `subj_title` VARCHAR(256) NULL ,
  `subj_comment` VARCHAR(256) NULL ,
  `subj_url` VARCHAR(1024) NULL ,
  PRIMARY KEY (`subj_lid`) ,
  CONSTRAINT `FK_SUBJ_LID`
    FOREIGN KEY (`subj_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION )
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`arch`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`arch` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`arch` (
  `arch_lid` INT NOT NULL ,
  `arch_opened` DATETIME NOT NULL ,
  `arch_closed` DATETIME NULL ,
  `arch_index` VARCHAR(256) NOT NULL ,
  `arch_period` TINYINT NOT NULL DEFAULT 0 ,
  `arch_ttl` TINYINT NOT NULL DEFAULT 0,
  `arch_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`arch_lid`) ,
  CONSTRAINT `FK_ARCH_LID`
    FOREIGN KEY (`arch_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION )
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`DATA`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`data` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`data` (
  `data_lid` INT NOT NULL ,
  `data_storage_id` SMALLINT NOT NULL ,
  `data_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  `data_data` MEDIUMBLOB NOT NULL ,
  PRIMARY KEY (`data_lid`) ,
  CONSTRAINT `FK_DATA_LID`
    FOREIGN KEY (`data_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_DATA_STORAGE`
    FOREIGN KEY (`data_storage_id` )
    REFERENCES `vivdocs`.`storage` (`storage_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Organizations`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`org` ;

CREATE TABLE IF NOT EXISTS `vivdocs`.`org` (
  `org_lid` INT NOT NULL ,
  `org_name` VARCHAR(90) NOT NULL ,
  `org_isholding` TINYINT NOT NULL DEFAULT 0,
  `org_isglobal` TINYINT NOT NULL DEFAULT 0,
  `org_duplicateof` INT NULL,
  `org_officialname` VARCHAR(127) NULL,
  `org_country` CHAR(3) NULL,
  `org_region` VARCHAR(8) NULL,
  `org_ogrn` CHAR(13) NULL,
  `org_inn` VARCHAR(12) NULL,
  `org_okpo` VARCHAR(10) NULL,
  `org_kpp` VARCHAR(16) NULL ,
  `org_business` VARCHAR(127) NULL ,
  PRIMARY KEY (`org_lid`) ,
  CONSTRAINT `FK_LID`
    FOREIGN KEY (`org_lid`)
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE )
ENGINE = InnoDB;

CREATE INDEX IDX_ORG_NAME ON `vivdocs`.`org` (`org_name` ASC);
CREATE INDEX IDX_ORG_OFFICIAL ON `vivdocs`.`org` (`org_officialname` ASC);
CREATE INDEX IDX_ORG_GL ON `vivdocs`.`org` (`org_isglobal` ASC);
CREATE INDEX IDX_ORG_H ON `vivdocs`.`org` (`org_isholding` ASC);
CREATE INDEX IDX_ORG_COUNTRY ON `vivdocs`.`org` (`org_country` ASC);
CREATE INDEX IDX_ORG_REGION ON `vivdocs`.`org` (`org_region` ASC);
CREATE INDEX IDX_ORG_OGRN ON `vivdocs`.`org` (`org_ogrn` ASC);
CREATE INDEX IDX_ORG_OKPO ON `vivdocs`.`org` (`org_okpo` ASC);
CREATE INDEX IDX_ORG_INN ON `vivdocs`.`org` (`org_inn` ASC);

-- -----------------------------------------------------
-- Table `vivdocs`.`Departments`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`dep` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`dep` (
  `dep_lid` INT NOT NULL ,
  `dep_name` VARCHAR(127) NOT NULL ,
  `dep_index` VARCHAR(16) DEFAULT NULL ,
  `dep_header_lid` INT NULL,
  PRIMARY KEY (`dep_lid`) ,
  CONSTRAINT `FK_DEP_LID`
    FOREIGN KEY (`dep_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_DEP_HEADER`
    FOREIGN KEY (`dep_header_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE )
ENGINE = InnoDB;

CREATE INDEX IDX_DEP_NAME ON `vivdocs`.`dep` (`dep_name` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`Employees`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`usr` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`usr` (
  `usr_lid` INT NOT NULL ,
  `usr_firstname` VARCHAR(45) NULL ,
  `usr_middleinitials` VARCHAR(45) NULL ,
  `usr_lastname` VARCHAR(45) NULL ,
  `usr_title` VARCHAR(90) NULL ,
  `usr_lastname_to` VARCHAR(45) NULL ,
  `usr_lastname_from` VARCHAR(45) NULL ,
  `usr_lastname_v` VARCHAR(45) NULL ,
  `usr_title_to` VARCHAR(90) NULL ,
  `usr_title_from` VARCHAR(90) NULL ,
  `usr_title_v` VARCHAR(90) NULL ,
  `usr_acatitle` VARCHAR(90) NULL ,
  `usr_acatitle_to` VARCHAR(90) NULL ,
  `usr_acatitle_from` VARCHAR(90) NULL ,
  `usr_acatitle_v` VARCHAR(90) NULL ,
  `usr_login` VARCHAR(45) NULL ,
  `usr_password` VARCHAR(127) NULL ,
  `usr_fired` DATETIME NULL ,
  `usr_ch` TINYINT NOT NULL DEFAULT 0,
  `usr_co` TINYINT NOT NULL DEFAULT 0,
  `usr_isglobal` TINYINT NOT NULL DEFAULT 0,
  `usr_prefnullcomm` TINYINT NOT NULL DEFAULT 0,
  `usr_calendar_id` SMALLINT NULL,
  `usr_digest` BINARY(96) NULL,
  `usr_netname` VARCHAR(255) NULL,
  PRIMARY KEY (`usr_lid`) ,
  CONSTRAINT `FK_USR_LID`
    FOREIGN KEY (`usr_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_USR_CALENDAR`
    FOREIGN KEY (`usr_calendar_id` )
    REFERENCES `vivdocs`.`calendar` (`calendar_id` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE )
ENGINE = InnoDB;

CREATE INDEX IDX_USR_FN ON `vivdocs`.`usr` (`usr_firstname` ASC) ;
CREATE INDEX IDX_USR_LN ON `vivdocs`.`usr` (`usr_lastname` ASC) ;
CREATE INDEX IDX_USR_MI ON `vivdocs`.`usr` (`usr_middleinitials` ASC) ;
CREATE INDEX IDX_USR_LOGIN ON `vivdocs`.`usr` (`usr_login` ASC) ;

CREATE INDEX IDX_USR_CH ON `vivdocs`.`usr` (`usr_ch` ASC) ;
CREATE INDEX IDX_USR_CO ON `vivdocs`.`usr` (`usr_co` ASC) ;
CREATE INDEX IDX_USR_GL ON `vivdocs`.`usr` (`usr_isglobal` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`Groups`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`grname` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`grname` (
  `grname_lid` INT NOT NULL ,
  `grname_md5` BINARY(16) NOT NULL ,
  PRIMARY KEY (`grname_lid`) ,
  UNIQUE INDEX `IDX_GRNAME_NAME_UNIQUE` (`grname_md5` ASC) ,
  CONSTRAINT `FK_GRNAME_LID`
    FOREIGN KEY (`grname_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE )
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`ServerAccess`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`acl` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`acl` (
  `acl_cnt_lid` INT NOT NULL ,
  `acl_add_lid` INT NULL ,
  `acl_usr_lid` INT NOT NULL ,
  `acl_plain` TINYINT NOT NULL ,
  `acl_level` TINYINT NOT NULL , 
  `acl_modified` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`acl_cnt_lid`,`acl_usr_lid`,`acl_plain`) ,
  INDEX `IDX_ACL_LEVEL` (`acl_level` ASC) ,
  CONSTRAINT `FK_ACL_CNT`
    FOREIGN KEY (`acl_cnt_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_ACL_ADD`
    FOREIGN KEY (`acl_add_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_ACL_OBJ`
    FOREIGN KEY (`acl_usr_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE )
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Pages`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`page`;

CREATE TABLE  `vivdocs`.`page` (
  `page_uid` BINARY(16) NOT NULL,
  `page_user_lid` INT NOT NULL,
  `page_idx` INT NOT NULL DEFAULT 0,
  `page_data` MEDIUMTEXT NULL,
  PRIMARY KEY  (`page_uid`) ,
  CONSTRAINT `FK_PAGE_USER`
    FOREIGN KEY (`page_user_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
) ENGINE=InnoDB;

CREATE INDEX IDX_PAGE_IDX ON `vivdocs`.`page` (`page_idx` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`UserPortlets`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`uportlet`;

CREATE TABLE  `vivdocs`.`uportlet` (
  `uportlet_uid` BINARY(16) NOT NULL,
  `uportlet_portlet_uid` BINARY(16) NOT NULL,
  `uportlet_page_uid` BINARY(16) NULL,
  `uportlet_user_lid` INT NULL,
  `uportlet_data` MEDIUMBLOB NULL,
  PRIMARY KEY  (`uportlet_uid`),
  CONSTRAINT `FK_UPORTLET_PORTLET`
    FOREIGN KEY (`uportlet_portlet_uid` )
    REFERENCES `vivdocs`.`portlet` (`portlet_uid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_UPORTLET_USER`
    FOREIGN KEY (`uportlet_user_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
) ENGINE=InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`EmployeesFoto`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`EmployeesFoto` ;

-- -----------------------------------------------------
-- Table `vivdocs`.`DocClasses`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`cclass` ;

CREATE TABLE IF NOT EXISTS `vivdocs`.`cclass` (
  `cclass_id` SMALLINT NOT NULL AUTO_INCREMENT ,
  `cclass_name` VARCHAR(255) ,
  `cclass_title` VARCHAR(127) ,
  PRIMARY KEY (`cclass_id`)
) ENGINE = InnoDB;

CREATE INDEX IDX_CLASS_NAME ON `vivdocs`.`cclass` (`cclass_name` ASC) ;
-- -----------------------------------------------------
-- Table `vivdocs`.`Registers`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`reg`;

CREATE TABLE IF NOT EXISTS `vivdocs`.`reg` (
  `reg_lid` INT NOT NULL,
  `reg_topic` VARCHAR(127) NULL,
  `reg_format` VARCHAR(45) NULL,
  `reg_category` VARCHAR(127) NULL,
  `reg_istemplate` TINYINT NOT NULL DEFAULT 0,
  `reg_created` DATETIME NULL,
  `reg_closed` DATETIME NULL,
  `reg_startfrom` INT NOT NULL DEFAULT 0,
  `reg_manager` INT DEFAULT NULL,
  PRIMARY KEY (`reg_lid`) ,
  CONSTRAINT `FK_REG_LID`
    FOREIGN KEY (`reg_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_REG_MANAGER`
    FOREIGN KEY (`reg_manager` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
) ENGINE = InnoDB;

CREATE INDEX IDX_REG_CREATED ON `vivdocs`.`reg` (`reg_created` ASC) ;
CREATE INDEX IDX_REG_CLOSED ON `vivdocs`.`reg` (`reg_closed` ASC) ;
CREATE INDEX IDX_REG_CATEGORY ON `vivdocs`.`reg` (`reg_category` ASC) ;


DROP TABLE IF EXISTS `vivdocs`.`nom` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`nom` (
  `nom_lid` INT NOT NULL ,
  `nom_year` SMALLINT NOT NULL DEFAULT 0,
  `nom_idx` VARCHAR(45) NULL ,
  PRIMARY KEY (`nom_lid`) ,
  CONSTRAINT `FK_NOM_LID`
    FOREIGN KEY (`nom_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  UNIQUE INDEX `IDX_NOM_IDX_UNIQUE` (`nom_year`,`nom_idx` ASC) )
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Documents`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`doc` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`doc` (
  `doc_lid` INT NOT NULL ,
  `doc_template_lid` INT NOT NULL,
  `doc_reg_lid` INT NULL,
  `doc_idx0` INT NOT NULL DEFAULT 0,
  `doc_idx1` INT NOT NULL DEFAULT 0,
  `doc_regdate` DATETIME NULL ,
  `doc_regnumber` VARCHAR(90) NULL ,
  `doc_registrated` TINYINT NOT NULL DEFAULT 0 ,
  `doc_isconfidential` TINYINT NOT NULL DEFAULT 0 ,
  `doc_doctype` TINYINT NOT NULL,
  `doc_extnumber` VARCHAR(90) NULL ,
  `doc_extdate` DATETIME NULL ,
  PRIMARY KEY (`doc_lid`) ,
  CONSTRAINT `FK_DOC_LID`
    FOREIGN KEY (`doc_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_DOC_REG`
    FOREIGN KEY (`doc_reg_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE )
ENGINE = InnoDB;

CREATE INDEX IDX_DOC_REGDATE ON `vivdocs`.`doc` (`doc_regdate` DESC) ;
CREATE INDEX IDX_DOC_REGNUMBER ON `vivdocs`.`doc` (`doc_regnumber` ASC) ;
CREATE INDEX IDX_DOC_EXTNUMBER ON `vivdocs`.`doc` (`doc_extnumber` ASC) ;
CREATE INDEX IDX_DOC_EXTDATE ON `vivdocs`.`doc` (`doc_extdate` ASC) ;
CREATE INDEX IDX_DOC_DOCTYPE ON `vivdocs`.`doc` (`doc_doctype` ASC) ;

CREATE INDEX IDX_DOC_IDX0 ON `vivdocs`.`doc` (`doc_idx0` ASC) ;
CREATE INDEX IDX_DOC_IDX1 ON `vivdocs`.`doc` (`doc_idx1` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`DocsRelation`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`docrel` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`docrel` (
	`docrel_doc_lid` INT NOT NULL ,
	`docrel_relatedto_lid` INT NOT NULL ,
	`docrel_relation` INT NOT NULL DEFAULT 0 ,
	`docrel_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
	PRIMARY KEY (`docrel_doc_lid`, `docrel_relatedto_lid`) ,
	CONSTRAINT `FK_DOCREL_DOC`
    	FOREIGN KEY (`docrel_doc_lid` )
    	REFERENCES `vivdocs`.`cnt` (`lid` )
    	ON DELETE CASCADE
    	ON UPDATE CASCADE ,
	CONSTRAINT `FK_DOCREL_TO`
    	FOREIGN KEY (`docrel_relatedto_lid` )
    	REFERENCES `vivdocs`.`cnt` (`lid` )
    	ON DELETE CASCADE
    	ON UPDATE CASCADE)
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Correspondens`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`corr` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`corr` (
	`corr_doc_lid` INT NOT NULL ,
	`corr_corr_lid` INT NOT NULL ,
	`corr_org_lid` INT NOT NULL ,
	`corr_relation` INT NOT NULL DEFAULT 0, 
	PRIMARY KEY (`corr_doc_lid`, `corr_corr_lid`) ,
	CONSTRAINT `FK_CORR_DOC`
    	FOREIGN KEY (`corr_doc_lid` )
    	REFERENCES `vivdocs`.`cnt` (`lid` )
    	ON DELETE CASCADE
    	ON UPDATE CASCADE ,
	CONSTRAINT `FK_CORR_CORR`
    	FOREIGN KEY (`corr_corr_lid` )
    	REFERENCES `vivdocs`.`cnt` (`lid` )
    	ON DELETE CASCADE
    	ON UPDATE CASCADE ,
	CONSTRAINT `FK_CORR_ORG`
    	FOREIGN KEY (`corr_org_lid` )
    	REFERENCES `vivdocs`.`cnt` (`lid` )
    	ON DELETE CASCADE
    	ON UPDATE CASCADE)
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Tasks`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`task` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`task` (
  `task_lid` INT NOT NULL ,
  `task_modified` TIMESTAMP NOT NULL ,
  `task_history` TINYINT NOT NULL DEFAULT 0 ,
  `task_to_name` VARCHAR(127) NOT NULL ,
  `task_to_dep_lid` INT NOT NULL ,
  `task_from_name` VARCHAR(127) NOT NULL ,
  `task_from_dep_lid` INT NOT NULL ,
  `task_ctrl_name` VARCHAR(127) NOT NULL ,
  `task_ctrl_dep_lid` INT NOT NULL ,
  `task_closed` TIMESTAMP NULL ,
  `task_parent_lid` INT NULL ,
  `task_thread_lid` INT NULL ,
  `task_start_date` TIMESTAMP NULL ,
  `task_runtype` TINYINT NOT NULL DEFAULT 0,
  `task_dtch_denied` TINYINT NOT NULL DEFAULT 0,
  `task_isconfidential` TINYINT NOT NULL DEFAULT 0,
  `task_alert_days` INT NOT NULL DEFAULT 0,
  `task_alert_date` TIMESTAMP NULL ,
  `task_importance` TINYINT NOT NULL DEFAULT 0 ,
  `task_routin_id` INT NULL ,
  `task_ctrl_date` TIMESTAMP NULL ,
  `task_status` TINYINT NOT NULL DEFAULT 0,
  `task_procent` TINYINT NOT NULL DEFAULT 0 ,

  `task_review_version` TIMESTAMP NULL , 
  
  `task_requested_date` TIMESTAMP NULL ,
  `task_report_date` TIMESTAMP NULL ,
  `task_result` TINYINT NOT NULL DEFAULT 0 ,

  `task_subject` VARCHAR(255) NULL ,
  `task_comment` VARCHAR(255) NULL ,
  PRIMARY KEY (`task_lid`,`task_modified`) ,
  CONSTRAINT `FK_TASK_LID`
    FOREIGN KEY (`task_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_TASK_TO_DEP`
    FOREIGN KEY (`task_to_dep_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_TASK_FROM_DEP`
    FOREIGN KEY (`task_from_dep_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_TASK_CTRL_DEP`
    FOREIGN KEY (`task_ctrl_dep_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE )
ENGINE = InnoDB;

ALTER TABLE `vivdocs`.`task` ADD CONSTRAINT `FK_TASK_PARENT`
    FOREIGN KEY (`task_parent_lid` )
    REFERENCES `vivdocs`.`task` (`task_lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE;
ALTER TABLE `vivdocs`.`task` ADD CONSTRAINT `FK_TASK_THREAD`
    FOREIGN KEY (`task_thread_lid` )
    REFERENCES `vivdocs`.`task` (`task_lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE;

CREATE INDEX IDX_TASK_HISTORY ON `vivdocs`.`task` (`task_history` ASC) ;

CREATE INDEX IDX_TASK_TO ON `vivdocs`.`task` (`task_to_dep_lid` ASC) ;
CREATE INDEX IDX_TASK_FROM ON `vivdocs`.`task` (`task_from_dep_lid` ASC) ;
CREATE INDEX IDX_TASK_CTRL ON `vivdocs`.`task` (`task_ctrl_dep_lid` ASC) ;

CREATE INDEX IDX_TASK_CTRLDATE ON `vivdocs`.`task` (`task_ctrl_date` ASC) ;
CREATE INDEX IDX_TASK_STATUS ON `vivdocs`.`task` (`task_status` ASC) ;
CREATE INDEX IDX_TASK_RUNTYPE ON `vivdocs`.`task` (`task_runtype` ASC) ;

CREATE INDEX IDX_TASK_REVIEWVERSION ON `vivdocs`.`task` (`task_review_version` ASC);
CREATE INDEX IDX_TASK_ALERTDATE ON `vivdocs`.`task` (`task_alert_date` ASC);


-- -----------------------------------------------------
-- Table `vivdocs`.`Processing`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`processing` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`processing` (
  `processing_task_lid` INT NOT NULL ,
  `processing_site_id`  SMALLINT UNSIGNED NOT NULL ,
  `processing_task` INT NOT NULL ,
  PRIMARY KEY (`processing_task_lid`,`processing_site_id`,`processing_task`) ,
  CONSTRAINT `FK_PROC_TASK`
    FOREIGN KEY (`processing_task_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_PROC_SITE`
    FOREIGN KEY (`processing_site_id` )
    REFERENCES `vivdocs`.`site` (`site_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE )
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`ContentTable`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`cnt` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`cnt` (
  `lid` INT NOT NULL AUTO_INCREMENT,
  `uid` BINARY(16) NOT NULL ,
  `cnt_class_id` TINYINT NOT NULL,
  `cnt_public` TINYINT NOT NULL DEFAULT 0,
  `cnt_site_id` SMALLINT UNSIGNED NULL,
  `cnt_uiclass_id` SMALLINT NULL,
  `cnt_modified` TIMESTAMP NOT NULL ,
  `cnt_modifier_lid` INT NOT NULL ,
  `cnt_created` DATETIME NOT NULL ,
  `cnt_creator_lid` INT NOT NULL ,
  `cnt_dep_lid` INT NULL ,
  `cnt_parent_lid` INT NULL ,
  `cnt_items` MEDIUMINT NOT NULL DEFAULT 0 ,
  `cnt_expitems` MEDIUMINT NOT NULL DEFAULT 0 ,
  `cnt_size` INT NOT NULL DEFAULT 0 ,
  `cnt_removed` TINYINT NOT NULL DEFAULT 0 ,
  PRIMARY KEY (`lid`) ,
  UNIQUE INDEX `IDX_CNT_UID_UNIQUE` (`uid`,`cnt_class_id` ASC) ,
  CONSTRAINT `FK_CNT_UICLASS`
    FOREIGN KEY (`cnt_uiclass_id` )
    REFERENCES `vivdocs`.`uiclass` (`uiclass_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_CNT_SITE`
    FOREIGN KEY (`cnt_site_id` )
    REFERENCES `vivdocs`.`site` (`site_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE )
ENGINE = InnoDB;

ALTER TABLE `vivdocs`.`cnt` ADD CONSTRAINT `FK_CNT_MODIFIER`
    FOREIGN KEY (`cnt_modifier_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE;
ALTER TABLE `vivdocs`.`cnt` ADD CONSTRAINT `FK_CNT_CREATOR`
    FOREIGN KEY (`cnt_creator_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE;
ALTER TABLE `vivdocs`.`cnt` ADD CONSTRAINT `FK_CNT_DEP`
    FOREIGN KEY (`cnt_dep_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE;
ALTER TABLE `vivdocs`.`cnt` ADD CONSTRAINT `FK_CNT_PARENT`
    FOREIGN KEY (`cnt_parent_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE;

CREATE INDEX IDX_CNT_CREATED ON `vivdocs`.`cnt` (`cnt_created` ASC) ;
CREATE INDEX IDX_CNT_MODIFIED ON `vivdocs`.`cnt` (`cnt_modified` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`Categories`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`category`;

CREATE TABLE  `vivdocs`.`category` (
  `category_id` SMALLINT NOT NULL auto_increment,
  `category_name` VARCHAR(256) NULL,
  `category_modified` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `category_removed` TIMESTAMP NULL,
  `category_replaced` SMALLINT NULL,
  PRIMARY KEY  (`category_id`)
) ENGINE=InnoDB;

INSERT INTO `vivdocs`.`category` (`category_name`) VALUES ('нормативно-регламентирующие документы');
INSERT INTO `vivdocs`.`category` (`category_name`) VALUES ('организационно-распорядительные документы');

-- -----------------------------------------------------
-- Table `vivdocs`.`Content`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`content` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`content` (
  `content_container_lid` INT NOT NULL ,
  `content_content_lid` INT NOT NULL ,
  `content_category_id` SMALLINT NULL,
  `content_modified` TIMESTAMP NULL ON UPDATE CURRENT_TIMESTAMP,
  `content_remove` TINYINT NOT NULL DEFAULT 0 ,
  PRIMARY KEY (`content_container_lid`, `content_content_lid`) ,
  INDEX `IDX_CONTENT_MODIFIED` (`content_modified` ASC) ,
  INDEX `IDX_CONTENT_REMOVE` (`content_remove` ASC) ,
  CONSTRAINT `FK_CONTENT_CONTAINER`
    FOREIGN KEY (`content_container_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_CONTENT_CONTENT`
    FOREIGN KEY (`content_content_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `FK_CONTENT_CATEGORY`
    FOREIGN KEY (`content_category_id` )
    REFERENCES `vivdocs`.`category` (`category_id` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE )
ENGINE = InnoDB;



-- -----------------------------------------------------
-- Table `vivdocs`.`Storages`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`storage`;

CREATE TABLE  `vivdocs`.`storage` (
  `storage_id` SMALLINT NOT NULL AUTO_INCREMENT,
  `storage_opened` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP,
  `storage_closed` TIMESTAMP NULL,
  `storage_jndiname` VARCHAR(127) NULL,
  `storage_database` VARCHAR(127) NULL,
  `storage_user` VARCHAR(127) NULL,
  `storage_password` VARCHAR(127) NULL,
  PRIMARY KEY  (`storage_id`) )
ENGINE=InnoDB;


DROP TABLE IF EXISTS `vivdocs`.`mimetype`;

CREATE TABLE  `vivdocs`.`mimetype` (
  `mimetype_id` SMALLINT NOT NULL AUTO_INCREMENT,
  `mimetype_name` VARCHAR(127) NULL,
  PRIMARY KEY  (`mimetype_id`) ,
  UNIQUE INDEX `IDX_MIMETYPE_UNIQUE` (`mimetype_name` ASC) )
ENGINE=InnoDB;


DROP TABLE IF EXISTS `vivdocs`.`file`;

CREATE TABLE  `vivdocs`.`file` (
  `file_hash` BINARY(32) NOT NULL,
  `file_size` INT NOT NULL DEFAULT 0,
  `file_mimetype_id` SMALLINT NOT NULL ,
  `file_storage_id` SMALLINT NOT NULL ,
  PRIMARY KEY (`file_hash`) ,
  CONSTRAINT `FK_FILE_MIMETYPE`
    FOREIGN KEY (`file_mimetype_id` )
    REFERENCES `vivdocs`.`mimetype` (`mimetype_id` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_FILE_STORAGE`
    FOREIGN KEY (`file_storage_id` )
    REFERENCES `vivdocs`.`storage` (`storage_id` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE )
ENGINE=InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Attachments`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`attach` ;

CREATE  TABLE IF NOT EXISTS `vivdocs`.`attach` (
  `attach_lid` INT NOT NULL ,
  `attach_filename` CHAR(255) NOT NULL ,
  `attach_file_hash` BINARY(32) NULL ,
  `attach_storage_id` SMALLINT NOT NULL ,
  `attach_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  PRIMARY KEY (`attach_lid`) ,
  CONSTRAINT `FK_ATTACH_LID`
    FOREIGN KEY (`attach_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_ATTACH_FILE`
    FOREIGN KEY (`attach_file_hash` )
    REFERENCES `vivdocs`.`file` (`file_hash` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_ATTACH_STORAGE`
    FOREIGN KEY (`attach_storage_id` )
    REFERENCES `vivdocs`.`storage` (`storage_id` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE )
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Assistants`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`assistant` ;

CREATE TABLE IF NOT EXISTS `vivdocs`.`assistant` (
  `assistant_lid` INT NOT NULL ,
  `assistant_usr_lid` INT NOT NULL ,
  `assistant_assisttype` TINYINT NOT NULL DEFAULT 0 ,
  `assistant_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `assistant_validto` TIMESTAMP NULL ,
  PRIMARY KEY (`assistant_lid`, `assistant_usr_lid`) ,
  CONSTRAINT `FK_ASSISTANT_LID`
    FOREIGN KEY (`assistant_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_ASSISTANT_USR`
    FOREIGN KEY (`assistant_usr_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE )
ENGINE = InnoDB;

CREATE INDEX IDX_ASSISTANT_VALID ON `vivdocs`.`assistant` (`assistant_validto` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`Templates`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`template`;

CREATE TABLE  `vivdocs`.`template` (
  `template_lid` INT NOT NULL,
  `template_versionof` INT NULL,
  `template_name` VARCHAR(127) NOT NULL,
  `template_reg_category` VARCHAR(127) NULL,
  `template_regsearch` TINYINT DEFAULT 0,
  `template_deffolder_lid` INT NULL,
  `template_tmpfolder_lid` INT NULL,
  `template_dtopic` CHAR(127) NULL,
  `template_dtype` TINYINT NOT NULL DEFAULT 0,
  `template_addressing` TINYINT NOT NULL DEFAULT 0,
  PRIMARY KEY  (`template_lid`) ,
  CONSTRAINT `FK_TEMPLATE_LID`
    FOREIGN KEY (`template_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_TEMPLATE_DEFFOLDER`
    FOREIGN KEY (`template_deffolder_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_TEMPLATE_TMPFOLDER`
    FOREIGN KEY (`template_tmpfolder_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE ) 
ENGINE=InnoDB;

CREATE INDEX IDX_TEMPLATE_NAME ON `vivdocs`.`template` (`template_name` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`Routins`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`routin`;

CREATE TABLE  `vivdocs`.`routin` (
  `routin_id` INT NOT NULL AUTO_INCREMENT,
  `routin_uid` BINARY(16) NOT NULL,
  `routin_template_lid` INT NOT NULL,
  `routin_prev_id` INT NULL,
  `routin_data` BLOB NULL ,
  PRIMARY KEY  (`routin_id`) ,
  CONSTRAINT `FK_ROUTIN_TEMPLATE`
    FOREIGN KEY (`routin_template_lid` )
    REFERENCES `vivdocs`.`template` (`template_lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
) ENGINE=InnoDB;


-- -----------------------------------------------------
-- Table `vivdocs`.`AdminRequests`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`AdminRequests`;

CREATE TABLE  `vivdocs`.`AdminRequests` (
  `Created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `Host` CHAR(32) NULL,
  `Action` VARCHAR(127) NULL,
  `Data` MEDIUMTEXT NULL
) ENGINE=InnoDB;


-- -----------------------------------------------------
-- Table `vivdocs`.`Messages`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`message`;

CREATE TABLE  `vivdocs`.`message` (
  `message_uid` BINARY(16) NOT NULL ,
  `message_recipient` INT NOT NULL ,
  `message_sender` INT NULL ,
  `message_timestamp` TIMESTAMP NULL DEFAULT NULL ,
  `message_readed` TINYINT NOT NULL DEFAULT 0 ,
  `message_link` INT NULL ,
  `message_url` VARCHAR(256) NULL ,
  `message_text` MEDIUMTEXT NULL ,
  `message_linkinfo` VARCHAR(256) NULL ,
  `message_sended` TINYINT NOT NULL DEFAULT 0 ,
  PRIMARY KEY  (`message_uid`) ,
  CONSTRAINT `FK_MESSAGE_RECIPIENT`
    FOREIGN KEY (`message_recipient` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_MESSAGE_SENDER`
    FOREIGN KEY (`message_sender` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_MESSAGE_LINK`
    FOREIGN KEY (`message_link` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
) ENGINE=InnoDB;

CREATE INDEX IDX_MESSAGE_TIME ON `vivdocs`.`message` (`message_timestamp` DESC) ;
CREATE INDEX IDX_MESSAGE_SENDED ON `vivdocs`.`message` (`message_sended` ASC) ;
CREATE INDEX IDX_MESSAGE_READED ON `vivdocs`.`message` (`message_readed` ASC) ;


-- -----------------------------------------------------
-- Table `vivdocs`.`Constants`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`const`;

CREATE TABLE  `vivdocs`.`const` (
  `const_var` VARCHAR(32) NOT NULL,
  `const_val` VARCHAR(128) NULL,
  PRIMARY KEY  (`const_var`)
) ENGINE=InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`Comms`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`comm`;

CREATE TABLE  `vivdocs`.`comm` (
  `comm_id` int NOT NULL,
  `comm_contact` INT NOT NULL ,
  `comm_comment` VARCHAR(256) NULL ,
  `comm_type` SMALLINT NULL ,
  `comm_isprimary` TINYINT NOT NULL DEFAULT 0,
  `comm_ispublic` TINYINT NOT NULL DEFAULT 0 ,
  `comm_ispreffered` TINYINT NOT NULL DEFAULT 0 ,
  `comm_address` VARCHAR(256) NULL ,
  `comm_modified` TIMESTAMP NULL DEFAULT NULL ,
  PRIMARY KEY  (`comm_id`) ,
  CONSTRAINT `FK_COMM_CONTACT`
    FOREIGN KEY (`comm_contact` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE  
) ENGINE=InnoDB;

CREATE INDEX IDX_COMM_ADDRESS ON `vivdocs`.`comm` (`comm_address` ASC) ;
CREATE INDEX IDX_COMM_MODIFIED ON `vivdocs`.`comm` (`comm_modified` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`OrgCategories`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`Orgcat`;

CREATE TABLE  `vivdocs`.`Orgcat` (
  `id` MEDIUMINT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(64) NOT NULL ,
  `Values` VARCHAR(256) NOT NULL ,  
  PRIMARY KEY  (`id`)
) ENGINE=InnoDB;

-- -----------------------------------------------------
-- Table `vivdocs`.`OrgCategoriesRelation`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`Orgcrel`;

CREATE TABLE  `vivdocs`.`Orgcrel` (
  `Org` INT NOT NULL ,
  `Category` MEDIUMINT NOT NULL ,
  `Value` VARCHAR(32) NOT NULL ,  
  PRIMARY KEY  (`Org`,`Category`) ,
  CONSTRAINT `ct_Orgcrel_Org`
    FOREIGN KEY (`Org` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `ct_Orgcrel_Cat`
    FOREIGN KEY (`Category` )
    REFERENCES `vivdocs`.`Orgcat` (`ID` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
) ENGINE=InnoDB;

CREATE INDEX Orgcat_Value ON `vivdocs`.`Orgcrel` (`Value` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`LISTENERS`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`listener`;

CREATE TABLE  `vivdocs`.`listener` (
  `listener_obj_lid` INT NOT NULL ,
  `listener_requestor_lid` INT NOT NULL ,
  `listener_statuschange` TINYINT NOT NULL DEFAULT 0,
  `listener_overdue` TINYINT NOT NULL DEFAULT 0,
  `listener_modify` TINYINT NOT NULL DEFAULT 0,
  PRIMARY KEY  (`listener_obj_lid`,`listener_requestor_lid`),
  CONSTRAINT `FK_LISTENER_OBJ`
    FOREIGN KEY (`listener_obj_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_LISTENER_REQUESTOR`
    FOREIGN KEY (`listener_requestor_lid` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE CASCADE
    ON UPDATE CASCADE  
) ENGINE=InnoDB;

CREATE INDEX LISTENERS_SC ON `vivdocs`.`listener` (`listener_statuschange` ASC) ;
CREATE INDEX LISTENERS_OD ON `vivdocs`.`listener` (`listener_overdue` ASC) ;
CREATE INDEX LISTENERS_M ON `vivdocs`.`listener` (`listener_modify` ASC) ;


-- -----------------------------------------------------
-- Table `vivdocs`.`DELEGATION_RULES`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`rule`;

CREATE TABLE  `vivdocs`.`rule` (
  `rule_uid` BINARY (16) NOT NULL ,
  `rule_owner` INT NOT NULL ,
  `rule_type` MEDIUMINT NOT NULL DEFAULT 0 ,
  `rule_enabled` TINYINT NOT NULL DEFAULT 0 ,
  `rule_from_date` TIMESTAMP NULL ,
  `rule_to_date` TIMESTAMP NULL ,
  `rule_order` MEDIUMINT NOT NULL DEFAULT 0 ,
  `rule_delegated` INT NOT NULL ,
  `rule_xml` MEDIUMTEXT NULL ,
  PRIMARY KEY  (`rule_uid`) ,
  CONSTRAINT `FK_RULE_OWNER`
    FOREIGN KEY (`rule_owner` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE ,
  CONSTRAINT `FK_RULE_DELEGATED`
    FOREIGN KEY (`rule_delegated` )
    REFERENCES `vivdocs`.`cnt` (`lid` )
    ON DELETE RESTRICT
    ON UPDATE CASCADE
) ENGINE=InnoDB;

CREATE INDEX DELEGATION_RULES_TY ON `vivdocs`.`rule` (`rule_type` ASC) ;
CREATE INDEX DELEGATION_RULES_OR ON `vivdocs`.`rule` (`rule_order` ASC) ;
CREATE INDEX DELEGATION_RULES_EN ON `vivdocs`.`rule` (`rule_enabled` ASC) ;
CREATE INDEX DELEGATION_RULES_FD ON `vivdocs`.`rule` (`rule_from_date` ASC) ;
CREATE INDEX DELEGATION_RULES_TD ON `vivdocs`.`rule` (`rule_to_date` ASC) ;

-- -----------------------------------------------------
-- Table `vivdocs`.`profiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `vivdocs`.`profile`;

CREATE TABLE  `vivdocs`.`profile` (
  `profile_name` VARCHAR(127) NOT NULL,
  `profile_modified` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP, 
  `profile_data` MEDIUMBLOB NULL,
  PRIMARY KEY  (`profile_name`)
) ENGINE=InnoDB;

INSERT INTO `vivdocs`.`const` (`const_var`,`const_val`) VALUES ('RELEASE','23');

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
